@@ -18,3 +18,6 @@ fies["./test.txt"] = "hogehoge"
 
 # プレーンテキスト読み込み
 print(fies["./test.txt"])
+
+# フォーマット指定書き出し
+fies["./test.myext", "json"] = {"hoge": 23, "dummy_data": "fuga"}
